[asterisk-commits] rmudgett: branch rmudgett/bridge_phase r387787 - in /team/rmudgett/bridge_pha...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Mon May 6 16:38:03 CDT 2013


Author: rmudgett
Date: Mon May  6 16:38:01 2013
New Revision: 387787

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=387787
Log:
Rename ast_bridge_local_optimized_out() to ast_bridge_unreal_optimized_out() with associated comments updated.

Modified:
    team/rmudgett/bridge_phase/channels/chan_local.c
    team/rmudgett/bridge_phase/include/asterisk/bridging.h
    team/rmudgett/bridge_phase/main/bridging.c

Modified: team/rmudgett/bridge_phase/channels/chan_local.c
URL: http://svnview.digium.com/svn/asterisk/team/rmudgett/bridge_phase/channels/chan_local.c?view=diff&rev=387787&r1=387786&r2=387787
==============================================================================
--- team/rmudgett/bridge_phase/channels/chan_local.c (original)
+++ team/rmudgett/bridge_phase/channels/chan_local.c Mon May  6 16:38:01 2013
@@ -452,11 +452,10 @@
 		return 0;
 	}
 	if (ast == p->owner) {
-/* BUGBUG need to rename ast_bridge_local_optimized_out() to ast_bridge_unreal_optimized_out(). */
-		return ast_bridge_local_optimized_out(p->owner, p->chan);
+		return ast_bridge_unreal_optimized_out(p->owner, p->chan);
 	}
 	if (ast == p->chan) {
-		return ast_bridge_local_optimized_out(p->chan, p->owner);
+		return ast_bridge_unreal_optimized_out(p->chan, p->owner);
 	}
 	/* ast is not valid to optimize. */
 	return 0;

Modified: team/rmudgett/bridge_phase/include/asterisk/bridging.h
URL: http://svnview.digium.com/svn/asterisk/team/rmudgett/bridge_phase/include/asterisk/bridging.h?view=diff&rev=387787&r1=387786&r2=387787
==============================================================================
--- team/rmudgett/bridge_phase/include/asterisk/bridging.h (original)
+++ team/rmudgett/bridge_phase/include/asterisk/bridging.h Mon May  6 16:38:01 2013
@@ -864,18 +864,18 @@
 int ast_bridge_unsuspend(struct ast_bridge *bridge, struct ast_channel *chan);
 
 /*!
  * \brief Check and optimize out the local channels between bridges.
  * \since 12.0.0
  *
  * \param chan Local channel writing a frame into the channel driver.
  * \param peer Other local channel in the pair.
  *
  * \note It is assumed that chan is already locked.
  *
- * \retval 0 if local channels were not optimized out.
- * \retval non-zero if local channels were optimized out.
- */
-int ast_bridge_local_optimized_out(struct ast_channel *chan, struct ast_channel *peer);
+ * \retval 0 if unreal channels were not optimized out.
+ * \retval non-zero if unreal channels were optimized out.
+ */
+int ast_bridge_unreal_optimized_out(struct ast_channel *chan, struct ast_channel *peer);
 
 /*!
  * \brief Try locking the bridge_channel.
@@ -864,18 +864,18 @@
 
 /*!
- * \brief Check and optimize out the local channels between bridges.
- * \since 12.0.0
- *
- * \param chan Local channel writing a frame into the channel driver.
- * \param peer Other local channel in the pair.
+ * \brief Check and optimize out the unreal channels between bridges.
+ * \since 12.0.0
+ *
+ * \param chan Unreal channel writing a frame into the channel driver.
+ * \param peer Other unreal channel in the pair.
  *
  * \note It is assumed that chan is already locked.

Modified: team/rmudgett/bridge_phase/main/bridging.c
URL: http://svnview.digium.com/svn/asterisk/team/rmudgett/bridge_phase/main/bridging.c?view=diff&rev=387787&r1=387786&r2=387787
==============================================================================
--- team/rmudgett/bridge_phase/main/bridging.c (original)
+++ team/rmudgett/bridge_phase/main/bridging.c Mon May  6 16:38:01 2013
@@ -3530,10 +3530,10 @@
 
 /*!
  * \internal
  * \brief Lock the local channel stack for chan and prequalify it.
  * \since 12.0.0
  *
  * \param chan Local channel writing a frame into the channel driver.
  *
  * \note It is assumed that chan is already locked.
  *
@@ -3573,10 +3573,10 @@
 
 /*!
  * \internal
  * \brief Lock the local channel stack for peer and prequalify it.
  * \since 12.0.0
  *
  * \param peer Other local channel in the pair.
  *
  * \retval bridge on success with bridge, bridge_channel, and peer locked.
  * \retval NULL if cannot do optimization now.
@@ -3621,7 +3621,7 @@
 
 /*!
  * \internal
  * \brief Check and attempt to swap optimize out the local channels.
  * \since 12.0.0
  *
  * \param chan_bridge
@@ -3629,9 +3629,9 @@
  * \param peer_bridge
  * \param peer_bridge_channel
  *
  * \retval 1 if local channels failed to optimize out.
  * \retval 0 if local channels were not optimized out.
  * \retval -1 if local channels were optimized out.
  */
 static int check_swap_optimize_out(struct ast_bridge *chan_bridge,
 	struct ast_bridge_channel *chan_bridge_channel, struct ast_bridge *peer_bridge,
@@ -3702,7 +3702,7 @@
 
 /*!
  * \internal
  * \brief Check and attempt to merge optimize out the local channels.
  * \since 12.0.0
  *
  * \param chan_bridge
@@ -3710,8 +3710,8 @@
  * \param peer_bridge
  * \param peer_bridge_channel
  *
  * \retval 0 if local channels were not optimized out.
  * \retval -1 if local channels were optimized out.
  */
 static int check_merge_optimize_out(struct ast_bridge *chan_bridge,
 	struct ast_bridge_channel *chan_bridge_channel, struct ast_bridge *peer_bridge,
@@ -3752,7 +3752,7 @@
 	return res;
 }
 
-int ast_bridge_local_optimized_out(struct ast_channel *chan, struct ast_channel *peer)
+int ast_bridge_unreal_optimized_out(struct ast_channel *chan, struct ast_channel *peer)
 {
 	struct ast_bridge *chan_bridge;
 	struct ast_bridge *peer_bridge;
@@ -3530,10 +3530,10 @@
 /*!
  * \internal
- * \brief Lock the local channel stack for chan and prequalify it.
- * \since 12.0.0
- *
- * \param chan Local channel writing a frame into the channel driver.
+ * \brief Lock the unreal channel stack for chan and prequalify it.
+ * \since 12.0.0
+ *
+ * \param chan Unreal channel writing a frame into the channel driver.
  *
  * \note It is assumed that chan is already locked.
@@ -3573,10 +3573,10 @@
 /*!
  * \internal
- * \brief Lock the local channel stack for peer and prequalify it.
- * \since 12.0.0
- *
- * \param peer Other local channel in the pair.
+ * \brief Lock the unreal channel stack for peer and prequalify it.
+ * \since 12.0.0
+ *
+ * \param peer Other unreal channel in the pair.
  *
  * \retval bridge on success with bridge, bridge_channel, and peer locked.
@@ -3621,7 +3621,7 @@
 /*!
  * \internal
- * \brief Check and attempt to swap optimize out the local channels.
+ * \brief Check and attempt to swap optimize out the unreal channels.
  * \since 12.0.0
  *
@@ -3629,9 +3629,9 @@
  * \param peer_bridge_channel
  *
- * \retval 1 if local channels failed to optimize out.
- * \retval 0 if local channels were not optimized out.
- * \retval -1 if local channels were optimized out.
+ * \retval 1 if unreal channels failed to optimize out.
+ * \retval 0 if unreal channels were not optimized out.
+ * \retval -1 if unreal channels were optimized out.
  */
 static int check_swap_optimize_out(struct ast_bridge *chan_bridge,
@@ -3702,7 +3702,7 @@
 /*!
  * \internal
- * \brief Check and attempt to merge optimize out the local channels.
+ * \brief Check and attempt to merge optimize out the unreal channels.
  * \since 12.0.0
  *
@@ -3710,8 +3710,8 @@
  * \param peer_bridge_channel
  *
- * \retval 0 if local channels were not optimized out.
- * \retval -1 if local channels were optimized out.
+ * \retval 0 if unreal channels were not optimized out.
+ * \retval -1 if unreal channels were optimized out.
  */
 static int check_merge_optimize_out(struct ast_bridge *chan_bridge,




More information about the asterisk-commits mailing list